@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -52,6 +52,11 @@
 #include <windows.h>
 #include <QSysInfo>
 #endif
+
+#if defined (Q_OS_DARWIN) || defined (Q_OS_WIN)
+#include "pulsemanager.h"
+#endif /* defined (Q_OS_DARWIN) || defined (Q_OS_WIN) */
+
 /**
 @author Oleksandr Shneyder
 */
@@ -236,28 +241,6 @@ struct sshKey
 };
 
 
-//wrapper to send mouse events under windows in embedded mode
-#ifdef Q_OS_WIN
-class WWrapper : public QPushButton
-{
-    friend class ONMainWindow;
-};
-#include <QThread>
-#include <QMutex>
-class ONMainWindow;
-class WinServerStarter: public QThread
-{
-public:
-    enum daemon {X,SSH,PULSE};
-    WinServerStarter ( daemon server, ONMainWindow * par );
-    void run();
-private:
-    daemon mode;
-    ONMainWindow* parent;
-};
-#endif
-
-
 class SessTreeView : public QTreeView
 {
     Q_OBJECT
@@ -351,7 +334,8 @@ public:
     ONMainWindow ( QWidget *parent = 0 );
     ~ONMainWindow();
     static void installTranslator();
-    QString iconsPath ( QString fname );
+    QString iconsPath ( const QString &fname ) const;
+    QString images_resource_path (const QString &filename, const QString &base = "") const;
     static bool isServerRunning ( int port );
     void startNewSession();
     void suspendSession ( QString sessId );
@@ -578,12 +562,11 @@ public:
     QString internAppName ( const QString& transAppName,
                             bool* found=0l );
     void setEmbedSessionActionsEnabled ( bool enable );
-    bool startSshd();
+    bool startSshd (key_types key_type = RSA_KEY_TYPE);
     QSize getEmbedAreaSize();
 #ifdef Q_OS_WIN
     static QString cygwinPath ( const QString& winPath );
     void startXOrg();
-    void startPulsed();
     static bool haveCygwinEntry();
     static void removeCygwinEntry();
     static QString U3DevicePath()
@@ -624,7 +607,7 @@ private:
     bool embedMode;
     bool thinMode;
     QString statusString;
-    QString autostartApp;
+    QStringList autostartApps;
     bool cmdAutologin;
     int defaultLink;
     int defaultQuality;
@@ -794,7 +777,6 @@ private:
     bool runStartApp;
     bool ldapOnly;
     bool isScDaemonOk;
-    bool parecTunnelOk;
 #ifdef Q_OS_LINUX
     bool directRDP;
 #endif
@@ -833,20 +815,12 @@ private:
     QProcess *nxproxy;
 #ifndef Q_OS_WIN
     QProcess *sshd;
-    bool userSshd;
 #else
     QProcess *xorg;
     PROCESS_INFORMATION sshd;
     bool winSshdStarted;
     static QString u3Device;
-    bool pulseStarted;
 
-    QString pulseVersionTestOutput;
-    QProcess* pulseVersionTest;
-    bool pulseVersionIsLegacy;
-    QProcess* pulseServer;
-    QStringList pulseArgs;
-    QTimer* pulseTimer;
     int xDisplay;
     int sshdPort;
     bool winServersReady;
@@ -856,14 +830,6 @@ private:
 
     bool cyEntry;
 
-    QString pulseDir;
-    QString pulseBaseDir;
-    QString pulseRuntimeDir;
-    QString pulseCookieArg;
-    int pulsePort;
-    bool pulseNoRecord;
-
-    int esdPort;
     bool maximizeProxyWin;
     int proxyWinWidth;
     int proxyWinHeight;
@@ -876,6 +842,12 @@ private:
     QTextEdit* stInfo;
     int localDisplayNumber;
 
+#if defined (Q_OS_DARWIN) || defined (Q_OS_WIN)
+    QThread *pulseManagerThread;
+    PulseManager *pulseManager;
+#endif /* defined (Q_OS_DARWIN) || defined (Q_OS_WIN) */
+
+
     SVGFrame* ln;
     int tunnel;
     int sndTunnel;
@@ -961,7 +933,6 @@ private:
     bool soundParameter ( QString val );
     void printError ( QString param );
     void exportDefaultDirs();
-    QString createRSAKey();
     directory* getExpDir ( QString key );
     bool findInList ( const QString& uid );
     void setUsersEnabled ( bool enable );
@@ -1016,12 +987,16 @@ protected:
 #else
 private slots:
     void slotSetWinServersReady();
-    void startWinServers();
+    void startWinServers(key_types key_type = RSA_KEY_TYPE);
     void slotCheckXOrgLog();
     void slotCheckXOrgConnection();
-    void slotCheckPulse();
-    void slotStartParec ();
 #endif
+
+#if defined (Q_OS_DARWIN) || defined (Q_OS_WIN)
+private slots:
+    void pulseManagerWrapper ();
+#endif /* defined (Q_OS_DARWIN) || defined (Q_OS_WIN) */
+
 private slots:
     void slotAppDialog();
     void slotShowPassForm();
@@ -1151,7 +1126,6 @@ private slots:
     void slotAttachProxyWindow();
     void slotEmbedIntoParentWindow();
     void slotEmbedWindow();
-    void slotSndTunOk();
     void slotPCookieReady (	bool result,QString output,
                             int proc );
     void slotEmbedToolBar();
@@ -1205,7 +1179,6 @@ private:
 #endif
     void filterDesktops ( const QString& filter,
                           bool strict=false );
-    void generateHostKey(key_types key_type);
     void generateEtcFiles();
     QString u3DataPath();
     void cleanPortable();
@@ -1218,6 +1191,12 @@ private:
     QString getXDisplay();
 #endif
 
+    key_types check_key_type (key_types key_type);
+    QString key_type_to_string (key_types key_type);
+    std::size_t default_size_for_key_type (key_types key_type);
+    QString generateKey (key_types key_type, bool host_key = false);
+    QString createKeyBundle (key_types key_type = RSA_KEY_TYPE);
+
 ////////////////plugin stuff////////////////////
 #ifdef CFGPLUGIN
 public slots:
@@ -1263,4 +1242,23 @@ private slots:
 ////////////////end of plugin stuff////////////////////
 };
 
+#ifdef Q_OS_WIN
+#include <QThread>
+#include <QMutex>
+class ONMainWindow;
+class WinServerStarter: public QThread
+{
+public:
+    enum daemon {X,SSH};
+    WinServerStarter ( daemon server, ONMainWindow * par );
+    void run();
+    void set_ssh_key_type (ONMainWindow::key_types key_type);
+    ONMainWindow::key_types get_ssh_key_type ();
+private:
+    daemon mode;
+    ONMainWindow* parent;
+    ONMainWindow::key_types ssh_key_type_;
+};
+#endif
+
 #endif
