@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -33,6 +33,10 @@
 #include "x2gologdebug.h"
 #include <QApplication>
 #include <QDesktopWidget>
+#include <QSvgRenderer>
+#include <QPainter>
+#include <QImage>
+#include <QPixmap>
 #include "sessionexplorer.h"
 
 
@@ -121,7 +125,19 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
     editBut=new QPushButton ( this );
     editBut->setMouseTracking ( true );
     connect ( editBut,SIGNAL ( pressed() ),this,SLOT ( slotShowMenu() ) );
-    editBut->setIcon ( QIcon ( par->iconsPath ( "/16x16/preferences.png" ) ) );
+
+    /* Load our edit button SVG file. */
+    QSvgRenderer svg_renderer (par->images_resource_path ("/svg/hamburger.svg"));
+
+    /* Prepare image to render to with full transparency. */
+    QImage tmp_image (16, 16, QImage::Format_ARGB32);
+    tmp_image.fill (0x00000000);
+
+    /* Paint icon to the image. */
+    QPainter tmp_painter (&tmp_image);
+    svg_renderer.render (&tmp_painter);
+
+    editBut->setIcon ( QIcon ( QPixmap::fromImage (tmp_image) ) );
     editBut->setIconSize ( QSize ( 16,16 ) );
     editBut->setFixedSize ( 24,24 );
     editBut->setFlat ( true );
