@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -56,9 +56,10 @@
 static bool isLibSshInited=false;
 
 const QString SshMasterConnection::challenge_auth_code_prompts_[] = {
-  "Verification code:",            // GA   (http://github.com/google/google-authenticator)
-  "One-time password (OATH) for",  // OATH (http://www.nongnu.org/oath-toolkit/pam_oath.html)
-  "passcode:"                      // MOTP (http://motp.sourceforge.net)
+  "Verification code:",            // GA      (http://github.com/google/google-authenticator)
+  "One-time password (OATH) for",  // OATH    (http://www.nongnu.org/oath-toolkit/pam_oath.html)
+  "passcode:",                     // MOTP    (http://motp.sourceforge.net)
+  "Enter PASSCODE:"                // SecurID
 };
 
 
