@@ -1,7 +1,7 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
-*   Copyright (C) 2016 by Mihai Moldovan <ionic@ionic.de>                 *
+*   Copyright (C) 2016-2017 by Mihai Moldovan <ionic@ionic.de>            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +24,7 @@
 #include <QFont>
 #include <QFontInfo>
 #include <QObject>
+#include <QStringList>
 
 #include "x2goutils.h"
 #include "onmainwindow.h"
@@ -52,7 +53,12 @@ QString fixup_resource_URIs (const QString &res_path) {
 QString wrap_legacy_resource_URIs (const QString &res_path) {
   QString ret (res_path);
 
-  if (!(res_path.isEmpty ())) {
+  /*
+   * Skip empty or non-resource URIs.
+   * Assume all paths not starting with a colon are
+   * absolute, non-resource URIs.
+   */
+  if ((!(res_path.isEmpty ())) && (res_path.startsWith (':'))) {
     std::vector<QString> legacy_locations;
     legacy_locations.push_back (QString (":/icons/"));
     legacy_locations.push_back (QString (":/png/"));
@@ -93,7 +99,7 @@ QString convert_to_rich_text (const QString &text, bool force) {
   return (fixup_text);
 }
 
-void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_text, const QString &informative_text) {
+void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_text, const QString &informative_text, bool app_modal) {
   QString fixup_main_text (convert_to_rich_text (main_text));
   QString fixup_informative_text (convert_to_rich_text (informative_text, true));
 
@@ -101,16 +107,23 @@ void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_t
 
   msg_box.setTextFormat (Qt::RichText);
   msg_box.setInformativeText (fixup_informative_text);
-  msg_box.setWindowModality (Qt::WindowModal);
+
+  if (app_modal) {
+    msg_box.setWindowModality (Qt::ApplicationModal);
+  }
+  else {
+    msg_box.setWindowModality (Qt::WindowModal);
+  }
+
   msg_box.exec ();
 }
 
-void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text) {
-  show_RichText_Generic_MsgBox (QMessageBox::Warning, main_text, informative_text);
+void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text, bool app_modal) {
+  show_RichText_Generic_MsgBox (QMessageBox::Warning, main_text, informative_text, app_modal);
 }
 
-void show_RichText_ErrorMsgBox (const QString &main_text, const QString &informative_text) {
-  show_RichText_Generic_MsgBox (QMessageBox::Critical, main_text, informative_text);
+void show_RichText_ErrorMsgBox (const QString &main_text, const QString &informative_text, bool app_modal) {
+  show_RichText_Generic_MsgBox (QMessageBox::Critical, main_text, informative_text, app_modal);
 }
 
 QString git_changelog_extract_commit_sha (const QString &gitlog) {
@@ -194,13 +207,17 @@ void show_XQuartz_generic_error (const QString &main_error, const QString &addit
                                             "or\n"
                                             "<center><b>/Applications/Utilities/XQuartz.app</b></center>"));
 }
+#endif /* defined (Q_OS_DARWIN) */
 
+#ifdef Q_OS_UNIX
 QString add_to_path (const QString &orig_path, const QStringList &add, const bool back) {
   QString ret = orig_path;
   std::vector<bool> found;
 
   QStringList orig_path_list = orig_path.split (":");
 
+  x2goDebug << "path value at beginning: " << orig_path;
+
   /*
    * Clean up add list. We want to make sure no entry ends in a slash
    * and skip empty entries.
@@ -209,7 +226,8 @@ QString add_to_path (const QString &orig_path, const QStringList &add, const boo
   for (int i = 0; i < add.size (); ++i) {
     if (!(add[i].isEmpty ())) {
       if (add[i].right (1) == "/") {
-        QString tmp_elem = add[i].right (1);
+        QString tmp_elem = add[i];
+        tmp_elem.chop (1);
 
         if (!(tmp_elem.isEmpty ())) {
           tmp_clean_add.append (tmp_elem);
@@ -221,6 +239,8 @@ QString add_to_path (const QString &orig_path, const QStringList &add, const boo
     }
   }
 
+  x2goDebug << "tmp_clean_add: " << tmp_clean_add;
+
   /* Nothing to add, really... */
   if (tmp_clean_add.isEmpty ()) {
     return (ret);
@@ -235,7 +255,7 @@ QString add_to_path (const QString &orig_path, const QStringList &add, const boo
       bool tmp_found = false;
 
       for (QStringList::const_iterator cit2 = cit + 1; cit2 != end; ++cit2) {
-        if (*cit == *cit) {
+        if (*cit == *cit2) {
           tmp_found = true;
           break;
         }
@@ -247,6 +267,8 @@ QString add_to_path (const QString &orig_path, const QStringList &add, const boo
     }
   }
 
+  x2goDebug << "clean_add: " << clean_add;
+
   /* Nothing to add. */
   if (clean_add.isEmpty ()) {
     return (ret);
@@ -265,6 +287,10 @@ QString add_to_path (const QString &orig_path, const QStringList &add, const boo
     }
   }
 
+  for (std::size_t i = 0; i < found.size (); ++i) {
+    x2goDebug << "found entry i (" << i << ") in orig_path_list (" << clean_add[i] << "): " << found[i];
+  }
+
   if (back) {
     for (int i = 0; i < clean_add.size (); ++i) {
       if (!found[i]) {
@@ -280,6 +306,48 @@ QString add_to_path (const QString &orig_path, const QStringList &add, const boo
     }
   }
 
+  x2goDebug << "return value at end: " << ret;
+
   return (ret);
 }
-#endif /* defined (Q_OS_DARWIN) */
+
+QString find_binary (const QString &path, const QString &binary_name) {
+  QString ret = "";
+
+  if (!(binary_name.isEmpty ())) {
+    QString cur_path = "";
+    QString tmp_path = path;
+
+    if (path.isEmpty ()) {
+      tmp_path = "./";
+    }
+
+    QStringList path_list = tmp_path.split (":");
+
+    for (QStringList::const_iterator const_it = path_list.constBegin (); const_it != path_list.constEnd (); ++const_it) {
+      cur_path = *const_it;
+
+      if (cur_path.isEmpty ()) {
+        cur_path = "./";
+      }
+
+      cur_path = QDir (cur_path).absolutePath ();
+
+      cur_path += "/" + binary_name;
+
+      QFileInfo tmp_file_info = QFileInfo (cur_path);
+
+      if ((tmp_file_info.exists ()) && (tmp_file_info.isExecutable ())) {
+        ret = tmp_file_info.canonicalFilePath ();
+        break;
+      }
+      else {
+        x2goDebug << "Binary at " << cur_path << " either does not exist (" << !(tmp_file_info.exists ())
+                  << ") or is not executable (" << tmp_file_info.isExecutable () << ")";
+      }
+    }
+  }
+
+  return (ret);
+}
+#endif /* defined (Q_OS_UNIX) */
