@@ -1,7 +1,7 @@
 /**************************************************************************
-*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
-*   Copyright (C) 2016 by Mihai Moldovan <ionic@ionic.de>                 *
+*   Copyright (C) 2016-2017 by Mihai Moldovan <ionic@ionic.de>            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -33,9 +33,9 @@ QString wrap_legacy_resource_URIs (const QString &res_path);
 
 QString convert_to_rich_text (const QString &text, bool force = false);
 
-void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_text, const QString &informative_text);
-void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text = "");
-void show_RichText_ErrorMsgBox (const QString &main_text, const QString &informative_text = "");
+void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_text, const QString &informative_text, bool app_modal = false);
+void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text = "", bool app_modal = false);
+void show_RichText_ErrorMsgBox (const QString &main_text, const QString &informative_text = "", bool app_modal = false);
 
 QString git_changelog_extract_commit_sha (const QString &gitlog);
 
@@ -45,7 +45,9 @@ bool font_is_monospaced (const QFont &font);
 void show_XQuartz_not_found_error ();
 void show_XQuartz_start_error ();
 void show_XQuartz_generic_error (const QString &main_error, const QString &additional_info);
+#endif /* defined (Q_OS_DARWIN) */
 
+#ifdef Q_OS_UNIX
 /*
  * Add a list of strings to a PATH value.
  *
@@ -57,6 +59,14 @@ void show_XQuartz_generic_error (const QString &main_error, const QString &addit
  * Ex.: <add_entry1>:<add_entry2>:...:<orig_path>
  */
 QString add_to_path (const QString &orig_path, const QStringList &add, const bool back = true);
-#endif /* defined (Q_OS_DARWIN) */
+
+/*
+ * Returns the first existing path that contains binary_name.
+ * Iff no component contains a binary called binary_name, an empty path is returned.
+ *
+ * Iff path is empty, (only) the current working dir is searched.
+ */
+QString find_binary (const QString &path, const QString &binary_name);
+#endif /* defined (Q_OS_UNIX) */
 
 #endif /* !defined (X2GOUTILS_H) */
